/*
 * Zynaptic Stash - An asynchronous persistence framework for Java.
 * 
 * Copyright (c) 2009-2015, Zynaptic Limited. All rights reserved. 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 2 only, as published by
 * the Free Software Foundation. Zynaptic Limited designates this particular
 * file as subject to the "Classpath" exception as provided in the LICENSE
 * file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version 2
 * along with this work; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please visit www.zynaptic.com or contact reaction@zynaptic.com if you need
 * additional information or have any questions.
 */

package com.zynaptic.stash.core;

import java.io.IOException;
import java.io.PrintStream;

import com.zynaptic.reaction.Deferred;

/**
 * Provides a placeholder stash record entry for use while setting up new stash
 * entries.
 * 
 * @author Chris Holgate
 * 
 */
public final class StashPlaceholderRecord extends StashEntryRecord<Boolean> {

  // Define the common metadata object which is used for all placeholder
  // records.
  private static final StashObjectMetadata<Boolean> PLACEHOLDER_METADATA =
      new StashObjectMetadata<Boolean>(
          StashObjectMetadata.RecordFormat.PLACEHOLDER, null, "PLACEHOLDER",
          false);

  /**
   * Provides default constructor which assigns the common placeholder metadata
   * to the superclass.
   */
  protected StashPlaceholderRecord() {
    super(PLACEHOLDER_METADATA);
  }

  /*
   * Implements StashEntryRecord.invalidate()
   */
  @Override
  public Deferred<Boolean> invalidate() {
    return null;
  }

  /*
   * Implements StashEntryRecord.reportRecordContents(...)
   */
  @Override
  public void reportRecordContents(PrintStream printStream) throws IOException {
    // No record state to report.
  }
}
